(function () {
  window.addEventListener('load', function () {
    if ('serviceWorker' in navigator) {
      navigator.serviceWorker.register('/firebase-messaging-sw.js')
        .then(function (registration) {
          const appScript = document.createElement('script');
          appScript.src = 'https://www.gstatic.com/firebasejs/10.7.0/firebase-app-compat.js';
          appScript.onload = function () {
            const msgScript = document.createElement('script');
            msgScript.src = 'https://www.gstatic.com/firebasejs/10.7.0/firebase-messaging-compat.js';
            msgScript.onload = function () {
              if (firebase.messaging.isSupported()) {
                const firebaseConfig = drupalSettings.firebase_ui;
                firebase.initializeApp(firebaseConfig);
                const messaging = firebase.messaging();
                Notification.requestPermission().then((permission) => {
                  if (permission === "granted") {
                    messaging.getToken({
                      vapidKey: firebaseConfig.vapidKey,
                      serviceWorkerRegistration: registration
                    }).then((currentToken) => {
                      if (currentToken) {
                        console.log("Firebase Token:", currentToken);
                        fetch('/firebase-ui/save-token', {
                          method: 'POST',
                          headers: {
                            'Content-Type': 'application/json',
                            'X-CSRF-Token': drupalSettings.csrfToken
                          },
                          body: JSON.stringify({
                            token: currentToken
                          })
                        });
                      } else {
                        console.warn("No token received.");
                      }
                    }).catch((err) => {
                      console.error("Error getting token:", err);
                    });
                  }
                });
              } else {
                console.warn("Firebase Messaging is not supported in this browser.");
              }
            };
            document.head.appendChild(msgScript);
          };
          document.head.appendChild(appScript);
        })
        .catch(function (error) {
          console.error("Service Worker registration failed:", error);
        });
    } else {
      console.warn("Service workers are not supported.");
    }
  });
})();
