<?php

namespace Drupal\firebase_ui\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Controller\ControllerBase;

/**
 * Controller to handle Firebase UI token saving.
 */
class FirebaseUiController extends ControllerBase {

  /**
   * Saves a Firebase token for the authenticated user.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request object.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response indicating success or failure.
   */
  public function saveToken(Request $request): JsonResponse {
    $data = json_decode($request->getContent(), TRUE);
    $token = $data['token'] ?? NULL;

    $current_user = $this->currentUser();

    if (!$current_user->isAuthenticated() || !$token) {
      return new JsonResponse(['status' => 'error'], 403);
    }

    /** @var \Drupal\user\UserInterface $account */
    $account = $this->entityTypeManager()->getStorage('user')->load($current_user->id());

    $tokens = $account->get('field_firebase_tokens')->getValue();
    $existing_tokens = array_column($tokens, 'value');

    if (!in_array($token, $existing_tokens, TRUE)) {
      $tokens[] = ['value' => $token];
      $account->set('field_firebase_tokens', $tokens);
      $account->save();
    }

    return new JsonResponse(['status' => 'success']);
  }

}
